@@ -15,7 +15,7 @@ from typing import Iterable
 MODULE_PATH = os.path.abspath(__file__).rsplit(os.path.sep, 4)[0]
 sys.path.insert(0, MODULE_PATH)
 
-from polygenic import version
+from polygenic.version import __version__
 from polygenic.lib.data_access.data_accessor import VcfAccessor
 
 from polygenic.lib.output import create_res_representation_for_model
@@ -117,7 +117,7 @@ def main(args = sys.argv[1:]):
     parser.add_argument('--mapping_json', type=str, default='', help="A file containing mapping between models and descriptions")
     parser.add_argument('--af', type=str, default='',
                         help="A file containing allele freq data")
-    parser.add_argument('-v', '--version', action='version', version='%(prog)s {}'.format(version))
+    parser.add_argument('-v', '--version', action='version', version='%(prog)s ' + __version__)
 
     parsed_args = parser.parse_args(args)
 
@@ -146,7 +146,9 @@ def main(args = sys.argv[1:]):
 
     # coupling model files with descriptions and plot data
     directories = [abspath_to_model_dir_from_repo(trait_dir) for trait_dir in parsed_args.traits_dirs] or []
+    print(directories)
     model_files_info = {}
+    print(model_files_info)
     # if parsed_args.mapping_json:
     #     with open(expand_path(parsed_args.mapping_json)) as f:
     #         models_descriptions_mappings = json.load(f)
@@ -156,7 +158,9 @@ def main(args = sys.argv[1:]):
     # elif parsed_args.models_and_descriptions_path:
     #     directories.append(parsed_args.models_and_descriptions_path)
     directories.append(parsed_args.models_and_descriptions_path)
+    print(directories)
     model_files_info.update(load_models_when_mapping_absent(directories, parsed_args.population, logger))
+    print(model_files_info)
     if not model_files_info:
         raise RuntimeError("No models loaded. Exiting.")
 
